@@ -41,6 +41,7 @@ class SequenceJob
     SequenceJob();
 
     CAPTUREResult capture(bool isDark=false);
+    void reset();
     void abort();
     void done();
     void prepareCapture();
@@ -63,15 +64,29 @@ class SequenceJob
     void setActiveChip(ISD::CCDChip *chip) { activeChip = chip; }
     ISD::CCDChip *getActiveChip() { return activeChip;}
 
+    void setFITSDir(const QString &dir) { fitsDir = dir;}
+    const QString & getFITSDir() { return fitsDir; }
+
     void setFilter(int pos, const QString & name);
+    int getFilterPos() { return filterPos;}
+    const QString &getFilterName() { return filter; }
     void setFrameType(int type, const QString & name);
+    int getFrameType() { return frameType;}
     void setCaptureFilter(FITSScale capFilter) { captureFilter = capFilter; }
     void setISOMode(bool mode) { isoMode = mode; }
+    bool getISOMode() { return isoMode;}
     void setPreview(bool enable) { preview = enable; }
     void setShowFITS(bool enable) { showFITS = enable; }
+    bool isShowFITS() { return showFITS;}
     void setPrefix(const QString &cprefix) { prefix = cprefix;}
     void setFrame(int in_x, int in_y, int in_w, int in_h) { x=in_x; y=in_y; w=in_w; h=in_h; }
+    int getSubX() { return x;}
+    int getSubY() { return y;}
+    int getSubW() { return w;}
+    int getSubH() { return h;}
     void setBin(int xbin, int ybin) { binX = xbin; binY=ybin;}
+    int getXBin() { return binX; }
+    int getYBin() { return binY; }
     void setDelay(int in_delay) { delay = in_delay; }
     void setCount(int in_count) { count = in_count;}
     void setImageType(int type) { imageType = type;}
@@ -81,6 +96,9 @@ class SequenceJob
 
     double getExposeLeft() const;
     void setExposeLeft(double value);
+    void resetStatus();
+    void setPrefixSettings(const QString &prefix, bool typeEnabled, bool filterEnabled, bool exposureEnabled);
+    void getPrefixSettings(QString &prefix, bool &typeEnabled, bool &filterEnabled, bool &exposureEnabled);
 
 private:
 
@@ -107,10 +125,13 @@ private:
     double exposeLeft;
     FITSScale captureFilter;
     QTableWidgetItem *statusCell;
+    QString fitsDir;
+
+    bool typePrefixEnabled, filterPrefixEnabled, expPrefixEnabled;
+    QString rawPrefix;
 
     JOBStatus status;
 
-
 };
 
 class Capture : public QWidget, public Ui::Capture
@@ -136,7 +157,7 @@ public:
     QString getLogText() { return logText.join("\n"); }
 
     /* Capture */
-    void updateSequencePrefix( const QString &newPrefix);
+    void updateSequencePrefix( const QString &newPrefix, const QString &dir);
 public slots:
 
     /* Capture */
@@ -166,8 +187,18 @@ public slots:
     void updateCaptureProgress(ISD::CCDChip *tChip, double value);
     void checkSeqBoundary(const KFileItemList & items);
 
+    void saveFITSDirectory();
+
     void setGuideChip(ISD::CCDChip* chip) { guideChip = chip; }
 
+    void loadSequenceQueue();
+    void saveSequenceQueue();
+    void saveSequenceQueueAs();
+
+    void resetJobs();
+    void editJob(QModelIndex i);
+    void resetJobEdit();
+
 signals:
         void newLog();
         void exposureComplete();
@@ -178,6 +209,9 @@ signals:
 private:
 
     void executeJob(SequenceJob *job);
+    bool processJobInfo(XMLEle *root);
+    bool saveSequenceQueue(const QString &path);
+    void constructPrefix(QString &imagePrefix);
 
     /* Capture */
     KDirLister          *seqLister;
@@ -213,6 +247,9 @@ private:
     INumberVectorProperty *filterSlot;
 
     QStringList logText;
+    KUrl sequenceURL;
+    bool mDirty;
+    bool jobUnderEdit;
 
     QProgressIndicator *pi;
 
