@@ -30,12 +30,20 @@ public:
     ~rguider();
 
     void guide( void );
+    void start();
+    void abort();
+    bool dither();
     void set_half_refresh_rate( bool is_half );
     bool is_guiding( void ) const;
     void set_math( cgmath *math );
+    void set_ao(bool enable);
     void fill_interface( void );
     void set_image(FITSView *image);
     void set_ready(bool enable) { is_ready = enable;}
+    void set_target_chip(ISD::CCDChip *chip);
+    bool isRapidGuide() { return useRapidGuide;}
+    bool is_dithering() { return isDithering; }
+    double get_ao_limit();
 
 protected slots:
 	void onXscaleChanged( int i );
@@ -46,11 +54,16 @@ protected slots:
 	void onEnableDirRA( int state );
 	void onEnableDirDEC( int state );
 	void onInputParamChanged();
-
+    void onRapidGuideChanged(bool enable);
+    void capture();
     void guideStarSelected(int x, int y);
-
 	void onStartStopButtonClick();
 
+signals:
+    void ditherComplete();
+    void ditherToggled(bool);
+    void autoGuidingToggled(bool, bool);
+
 private:
 	cgmath *pmath;
     Ekos::Guide *pmain_wnd;
@@ -61,10 +74,15 @@ private:
     FITSView *pimage;
 	bool is_started;
     bool is_ready;
+    bool is_subframed;
+    bool first_frame;
 	bool half_refresh_rate;
     int lost_star_try;
-
-
+    bool useRapidGuide;
+    ISD::CCDChip *targetChip;
+    int fx,fy,fw,fh;
+    double ret_x, ret_y, ret_angle;
+    bool isDithering;
 
 private:
     Ui::guiderClass ui;
