@@ -595,6 +595,7 @@ CCD::~CCD()
 #endif
     delete (primaryChip);
     delete (guideChip);
+    delete (streamWindow);
 }
 
 void CCD::registerProperty(INDI::Property *prop)
@@ -764,20 +765,29 @@ void CCD::processSwitch(ISwitchVectorProperty *svp)
         {
             streamWindow = new StreamWG();
 
-            INumberVectorProperty *ccdFrame = baseDevice->getNumber("CCD_FRAME");
+            // Only use CCD dimensions if we are receing raw stream and not stream of images (i.e. mjpeg..etc)
+            IBLOBVectorProperty *rawBP = baseDevice->getBLOB("CCD1");
+            if (rawBP)
+            {
+                INumberVectorProperty *ccdFrame = baseDevice->getNumber("CCD_FRAME");
 
-            if (ccdFrame == NULL)
-                return;
+                if (ccdFrame == NULL)
+                    return;
 
-            INumber *wd = IUFindNumber(ccdFrame, "WIDTH");
-            INumber *ht = IUFindNumber(ccdFrame, "HEIGHT");
+                INumber *wd = IUFindNumber(ccdFrame, "WIDTH");
+                INumber *ht = IUFindNumber(ccdFrame, "HEIGHT");
 
-            if (wd && ht)
-                streamWindow->setSize(wd->value, ht->value);
+                rawBP->bp[0].aux0 = &(wd->value);
+                rawBP->bp[0].aux1 = &(ht->value);
 
-            connect(streamWindow, SIGNAL(destroyed()), this, SLOT(StreamWindowDestroyed()));
+                if (wd && ht)
+                    streamWindow->setSize(wd->value, ht->value);
+            }
         }
 
+        streamWindow->disconnect();
+        connect(streamWindow, SIGNAL(hidden()), this, SLOT(StreamWindowHidden()));
+
         if (streamWindow)
         {
             if (svp->sp[0].s == ISS_ON)
@@ -821,19 +831,21 @@ void CCD::processText(ITextVectorProperty *tvp)
 void CCD::processBLOB(IBLOB* bp)
 {
 
+    QString format(bp->format);
+
     // If stream, process it first
-    if (!strcmp(bp->format, ".stream") && streamWindow)
+    if ( format.contains("stream") && streamWindow)
     {
         if (streamWindow->isStreamEnabled() == false)
             return;
 
         streamWindow->show();
-        streamWindow->newFrame( (static_cast<unsigned char *> (bp->blob)), bp->size, streamWindow->getWidth(), streamWindow->getHeight());
+        streamWindow->newFrame(bp);
         return;
     }
 
     // If it's not FITS, don't process it.
-    if (strcmp(bp->format, ".fits"))
+    if (format.contains("fits") == false)
     {
         DeviceDecorator::processBLOB(bp);
         return;
@@ -846,8 +858,7 @@ void CCD::processBLOB(IBLOB* bp)
     else
         targetChip = primaryChip;
 
-     // It's either FITS or OTHER
-    QString currentDir = Options::fitsDir();
+    QString currentDir =  fitsDir.isEmpty() ? Options::fitsDir() : fitsDir;
     int nr, n=0;
     KTemporaryFile tmpFile;
 
@@ -863,7 +874,7 @@ void CCD::processBLOB(IBLOB* bp)
     QString filename(currentDir + '/');
 
     // Create file name for FITS to be shown in FITS Viewer
-    if (targetChip->isBatchMode() == false || targetChip->getCaptureMode() != FITS_NORMAL)
+    if (Options::showFITS() && (targetChip->isBatchMode() == false || targetChip->getCaptureMode() != FITS_NORMAL))
     {
 
         tmpFile.setPrefix("fits");
@@ -915,7 +926,7 @@ void CCD::processBLOB(IBLOB* bp)
     // store file name
     strncpy(bp->label, filename.toLatin1(), MAXINDILABEL);
 
-    if (targetChip->isBatchMode() && targetChip->getCaptureMode() == FITS_NORMAL)
+    if ((targetChip->isBatchMode() && targetChip->getCaptureMode() == FITS_NORMAL) || Options::showFITS() == false)
         KStars::Instance()->statusBar()->changeItem( i18n("FITS file saved to %1", filename ), 0);
 
     if (targetChip->showFITS() == false && targetChip->getCaptureMode() == FITS_NORMAL)
@@ -943,7 +954,11 @@ void CCD::processBLOB(IBLOB* bp)
         switch (targetChip->getCaptureMode())
         {
             case FITS_NORMAL:
-                normalTabID = fv->addFITS(&fileURL, FITS_NORMAL, captureFilter);
+                if (normalTabID == -1 || Options::singlePreviewFITS() == false)
+                    normalTabID = fv->addFITS(&fileURL, FITS_NORMAL, captureFilter);
+                else if (fv->updateFITS(&fileURL, normalTabID, captureFilter) == false)
+                    normalTabID = fv->addFITS(&fileURL, FITS_NORMAL, captureFilter);
+
                 targetChip->setImage(fv->getImage(normalTabID), FITS_NORMAL);
                 break;
 
@@ -1026,14 +1041,8 @@ void CCD::FITSViewerDestroyed()
     normalTabID = calibrationTabID = focusTabID = guideTabID = -1;
 }
 
-void CCD::StreamWindowDestroyed()
+void CCD::StreamWindowHidden()
 {
-    if (streamWindow)
-    {
-        streamWindow->disconnect();
-        delete(streamWindow);
-        streamWindow = NULL;
-
         ISwitchVectorProperty *streamSP = baseDevice->getSwitch("VIDEO_STREAM");
         if (streamSP)
         {
@@ -1042,7 +1051,8 @@ void CCD::StreamWindowDestroyed()
             streamSP->s = IPS_IDLE;
             clientManager->sendNewSwitch(streamSP);
         }
-    }
+
+        streamWindow->disconnect();
 }
 
 bool CCD::hasGuideHead()
