@@ -87,11 +87,17 @@ void INDI_E::buildSwitch(QButtonGroup* groupB, ISwitch *sw)
     name  = sw->name;
     label = i18nc(libindi_strings_context, sw->label);
 
+    if (label == "(I18N_EMPTY_MESSAGE)")
+        label = sw->label;
+
     sp = sw;
 
     if (label.isEmpty())
         label = i18nc(libindi_strings_context, sw->name);
 
+    if (label == "(I18N_EMPTY_MESSAGE)")
+        label = sw->name;
+
     if (groupB == NULL)
         return;
 
@@ -136,16 +142,24 @@ void INDI_E::buildMenuItem(ISwitch *sw)
 void INDI_E::buildText(IText *itp)
 {
     name  = itp->name;
-    label = i18nc(libindi_strings_context, itp->label);
+    if (itp->label[0])
+        label = i18nc(libindi_strings_context, itp->label);
+
+    if (label == "(I18N_EMPTY_MESSAGE)")
+        label = itp->label;
 
     tp = itp;
 
     if (label.isEmpty())
         label = i18nc(libindi_strings_context, itp->name);
 
+    if (label == "(I18N_EMPTY_MESSAGE)")
+        label = itp->name;
+
     setupElementLabel();
 
-    text = i18nc(libindi_strings_context, tp->text);
+    if (tp->text[0])
+        text = i18nc(libindi_strings_context, tp->text);
 
     switch (dataProp->getPermission())
     {
@@ -320,11 +334,17 @@ void INDI_E::buildBLOB(IBLOB *ibp)
     name  = ibp->name;
     label = i18nc(libindi_strings_context, ibp->label);
 
+    if (label == "(I18N_EMPTY_MESSAGE)")
+        label = ibp->label;
+
     bp = ibp;
 
     if (label.isEmpty())
         label = i18nc(libindi_strings_context, ibp->name);
 
+    if (label == "(I18N_EMPTY_MESSAGE)")
+        label = ibp->name;
+
     setupElementLabel();
 
     text = i18n("INDI DATA STREAM");
@@ -359,11 +379,17 @@ void INDI_E::buildNumber  (INumber *inp)
     name  = inp->name;
     label = i18nc(libindi_strings_context, inp->label);
 
+    if (label == "(I18N_EMPTY_MESSAGE)")
+        label = inp->label;
+
     np = inp;
 
     if (label.isEmpty())
         label = i18nc(libindi_strings_context, inp->name);
 
+    if (label == "(I18N_EMPTY_MESSAGE)")
+        label = inp->name;
+
     numberFormat(iNumber, np->format, np->value);
     text = iNumber;
 
@@ -407,11 +433,17 @@ void INDI_E::buildLight(ILight *ilp)
     name  = ilp->name;
     label = i18nc(libindi_strings_context, ilp->label);
 
+    if (label == "(I18N_EMPTY_MESSAGE)")
+        label = ilp->label;
+
     lp = ilp;
 
     if (label.isEmpty())
         label = i18nc(libindi_strings_context, ilp->name);
 
+    if (label == "(I18N_EMPTY_MESSAGE)")
+        label = ilp->name;
+
     led_w = new KLed (guiProp->getGroup()->getContainer());
     led_w->setMaximumSize(16,16);
     led_w->setLook( KLed::Sunken );
