@@ -106,6 +106,11 @@ Q_OBJECT
          */
         void loadObservationTab();
 
+        /**@short get object name. If star has no name, generate a name based on catalog number.
+         * @param translated set to true if the translated name is required.
+         */
+        QString getObjectName(const SkyObject *o, bool translated=true);
+
         void selectNextTarget();
 
         void loadCurrentItems();
