@@ -19,6 +19,7 @@
 #define ASTEROIDSCOMPONENT_H
 
 #include "solarsystemlistcomponent.h"
+#include "datahandlers/ksparser.h"
 #include <QList>
 #include "typedef.h"
 
@@ -34,13 +35,14 @@ public:
     /**@short Default constructor.
      * @p parent pointer to the parent SolarSystemComposite
      */
-    AsteroidsComponent(SolarSystemComposite *parent);
+    explicit AsteroidsComponent(SolarSystemComposite *parent);
 
     virtual ~AsteroidsComponent();
     virtual void draw( SkyPainter *skyp );
     virtual bool selected();
     virtual SkyObject* objectNearest( SkyPoint *p, double &maxrad );
     void updateDataFile();
+    QString ans();
 private:
     void loadData();
 };
