@@ -44,8 +44,8 @@ ObsListWizard::ObsListWizard( QWidget *ksparent ) :
     setMainWidget( olw );
     setCaption( i18n("Observing List Wizard") );
     setButtons( KDialog::User1|KDialog::User2|KDialog::Ok|KDialog::Cancel );
-    setButtonGuiItem( KDialog::User2, KGuiItem( QString("< ") + i18n("&Back"), QString(), i18n("Go to previous Wizard page") ) );
-    setButtonGuiItem( KDialog::User1, KGuiItem( i18n("&Next") + QString(">"), QString(), i18n("Go to next Wizard page") ) );
+    setButtonGuiItem( KDialog::User2, KGuiItem( i18n("< &Back"), QString(), i18n("Go to previous Wizard page") ) );
+    setButtonGuiItem( KDialog::User1, KGuiItem( i18n("&Next >"), QString(), i18n("Go to next Wizard page") ) );
     enableButton( KDialog::User2, false );
 
     connect( olw->AllButton, SIGNAL( clicked() ), this, SLOT( slotAllButton() ) );
